@@ -133,6 +133,12 @@ normalize.initprobs.glm <- function(initprobs, glm.obj) {
 #' model.
 #' @param MCMC.iterations Number of models to sample when using any of the MCMC
 #' options; should be greater than 'n.models'. By default 10*n.models.
+#' @param thin oFr "MCMC", thin the MCMC chain every "thin" iterations; default 
+#' is no
+#' thinning.  For large p, thinning can be used to significantly reduce memory
+#' requirements as models and associated summaries are saved only every thin 
+#' iterations.  For thin = p, the  model and associated output are recorded 
+#' every p iterations,similar to the Gibbs sampler in SSVS.
 #' @param control a list of parameters that control convergence in the fitting
 #' process.  See the documentation for \code{glm.control()}
 #' @param laplace logical variable for whether to use a Laplace approximate for
@@ -240,7 +246,7 @@ bas.glm <- function(formula, family = binomial(link = "logit"),
                     update = NULL,
                     bestmodel = NULL,
                     prob.rw = 0.5,
-                    MCMC.iterations = NULL,
+                    MCMC.iterations = NULL, thin = 1,
                     control = glm.control(), laplace = FALSE, renormalize = FALSE,
                     force.heredity = FALSE,
                     bigmem = FALSE) {
@@ -463,6 +469,7 @@ bas.glm <- function(formula, family = binomial(link = "logit"),
       Rbestmodel = bestmodel,
       plocal = as.numeric(1.0 - prob.rw),
       BURNIN_Iterations = as.integer(MCMC.iterations),
+      Rthin = as.integer(thin),
       family = family, Rcontrol = control,
       Rlaplace = as.integer(laplace),
       Rparents = parents
